#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/libgweather/2.30/libgweather-2.30.2.tar.bz2
#
# maintainer: (package seek a maintainers)
#

#------------------ Set Some Variables

soft='libgweather'
softversion='2.30.2'
arch="i486"
cpu="i686"
packageversion="66.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# ----------------- Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --disable-static \
  --disable-schemas-install \
  --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# gconf stuff

export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
  if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
     gconftool-2 --makefile-install-rule $schema
done
# Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING INSTALL MAINTAINERS NEWS README \
  $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/libgweather html )

# we don't need help files

rm -rf $dest/usr/share/gnome
rm -rf $dest/usr/share/omf

mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

           |-----handy-ruler---------------------------------------------------|
libgweather: libgweather - a library to access weather information
libgweather:
libgweather: libgweather is a library to access weather information from online
libgweather: services for numerous locations
libgweather:
libgweather:
libgweather:
libgweather:
libgweather:
libgweather:
libgweather:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5